"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const _ = require("lodash");
const Webdriver = require("selenium-webdriver");
const errors_1 = require("./errors");
function prepareConfig(config) {
    /* tslint:disable-next-line:prefer-const */
    let prepared = _.cloneDeep(config);
    _.defaults(prepared, defaultConfig); // Mutates prepared
    validateConfig(prepared);
    return prepared;
}
exports.prepareConfig = prepareConfig;
const defaultConfig = {
    browser: "chrome",
    headless: false,
    logException: [],
    paths: getBinaryPaths(),
    sauceLabs: {},
    screenshotsDir: "./screenshots",
    serverUrl: "http://localhost:4444/wd/hub",
    threshold: 0.04,
    useProvidedDriver: false,
};
function getBinaryPaths() {
    const seleniumPath = "bin/selenium/";
    const geckoExe = path.resolve(seleniumPath, "geckodriver");
    const chromeExe = path.resolve(seleniumPath, "chromedriver");
    return {
        chromeExe,
        geckoExe,
        seleniumPath,
    };
}
function validateConfig(config) {
    const validBrowsers = [
        Webdriver.Browser.CHROME,
        Webdriver.Browser.FIREFOX,
        Webdriver.Browser.SAFARI,
        Webdriver.Browser.EDGE,
        Webdriver.Browser.INTERNET_EXPLORER,
    ];
    const isValidBrowser = _.includes(validBrowsers, config.browser);
    if (!config.useProvidedDriver && !isValidBrowser) {
        throw new Error(`Configuration error: Please set a "browser" of one of ${validBrowsers.join(", ")}.`);
    }
    const isValidThreshold = config.threshold && config.threshold >= 0 && config.threshold <= 0.99;
    if (!isValidThreshold) {
        throw new Error('Configuration error: Please set a "threshold" between 0 and 0.99');
    }
    const exceptions = [
        errors_1.ScreenshotExceptionName.MISMATCH,
        errors_1.ScreenshotExceptionName.NO_BASELINE,
        errors_1.ScreenshotExceptionName.SIZE_DIFFERENCE,
    ];
    const isValidLogException = config.logException.every((value) => exceptions.indexOf(value) >= 0);
    if (!isValidLogException) {
        throw new Error('Configuration error: "logException" should be an array with zero or more ' +
            `exception names: "${exceptions.join('", "')}".`);
    }
}
//# sourceMappingURL=config.js.map