"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Webdriver = require("selenium-webdriver");
const Firefox = require("selenium-webdriver/firefox");
function getDriver(config) {
    return __awaiter(this, void 0, void 0, function* () {
        const builder = new Webdriver.Builder()
            .usingServer(config.serverUrl)
            .forBrowser(config.browser);
        // saucelabs makes typescript ugly
        if (config.sauceLabs.tunnelIdentifier !== undefined) {
            config.sauceLabs["tunnel-identifier"] = config.sauceLabs.tunnelIdentifier;
        }
        if (config.browser === Webdriver.Browser.CHROME) {
            const capabilitiesChrome = Webdriver.Capabilities.chrome();
            const args = ["--no-sandbox"];
            if (config.headless) {
                args.push("--headless");
                if (config.initialViewportSize) {
                    args.push(`--window-size=${config.initialViewportSize.slice(0, 2).join(",")}`);
                }
            }
            capabilitiesChrome.merge(config.sauceLabs);
            capabilitiesChrome.set("chromeOptions", {
                args,
            });
            builder.withCapabilities(capabilitiesChrome);
        }
        if (config.browser === Webdriver.Browser.FIREFOX) {
            const capabilitiesFirefox = Webdriver.Capabilities.firefox();
            capabilitiesFirefox.merge(config.sauceLabs);
            if (config.headless) {
                const options = new Firefox.Options();
                const binary = new Firefox.Binary();
                binary.addArguments("-headless");
                options.setBinary(binary);
                builder.setFirefoxOptions(options);
            }
            builder.withCapabilities(capabilitiesFirefox);
        }
        if (config.browser === Webdriver.Browser.SAFARI) {
            const capabilitiesSafari = Webdriver.Capabilities.safari();
            capabilitiesSafari.merge(config.sauceLabs);
            builder.withCapabilities(capabilitiesSafari);
        }
        if (config.browser === Webdriver.Browser.EDGE) {
            const capabilitiesEdge = Webdriver.Capabilities.edge();
            capabilitiesEdge.merge(config.sauceLabs);
            builder.withCapabilities(capabilitiesEdge);
        }
        if (config.browser === Webdriver.Browser.INTERNET_EXPLORER) {
            const capabilitiesIe = Webdriver.Capabilities.ie();
            capabilitiesIe.merge(config.sauceLabs);
            builder.withCapabilities(capabilitiesIe);
        }
        const driver = builder.build();
        if (config.initialViewportSize) {
            yield driver.manage().window().setSize(config.initialViewportSize[0], config.initialViewportSize[1]);
        }
        return driver;
    });
}
exports.getDriver = getDriver;
//# sourceMappingURL=getDriver.js.map