import { WebElement } from "selenium-webdriver";
interface IScrollRect {
    height: number;
    width: number;
}
interface IClientRect extends IScrollRect {
    left: number;
    top: number;
}
interface IRect extends IClientRect {
    bottom: number;
    right: number;
}
export declare class Rect implements IRect {
    bottom: number;
    height: number;
    left: number;
    right: number;
    top: number;
    width: number;
    /**
     * Duplicate the Rect to a new object.
     */
    duplicate(): Rect;
    /**
     * Retrieve the Rect corresponding to the element's bounding box accounting for pixelRatio.
     * This method uses `getBoundingClientRect` but will round away subpixel values to the nearest pixel.
     * @param element The `WebElement` to fetch the Rect for.
     */
    forElement(element: WebElement): Promise<Rect>;
    /**
     * Retrieve the Rect corresponding to the viewport element's content. This is obtained by looking at the scroll
     * width and height of the viewport element and its scroll offsets, then mapping to the rect obtained via the
     * `forViewportElement` call.
     * @param element The `WebElement` to fetch the content Rect for.
     */
    forElementContent(element: WebElement): Promise<Rect>;
    /**
     * Retrieve the Rect corresponding to the viewport element's bounding box accounting for pixelRatio.
     * The viewport bounding box is defined as the bounding box of the area through which the element's content is
     * visible. This is found by adjusting the element's boundingRect by it's clientRect.
     * @param element The `WebElement` to fetch the viewport Rect for.
     */
    forViewportElement(element: WebElement): Promise<Rect>;
    /**
     * Transform position to relative pixels by the reference point (left, top).
     * @param rect `Rect` object containing the top, left coordinates.
     */
    relativeTo({ left, top }: Rect): Rect;
    /**
     * Wraps getBoundingClientRect.
     * @param element `WebElement` to retrieve the rect for.
     */
    private getBoundingRect;
    /**
     * Returns the client dimensions and offsets.
     * @param element `WebElement` to retrieve the rect for.
     */
    private getClientRect;
    /**
     * Returns the scroll offsets.
     * @param element `WebElement` to retrieve the rect for.
     */
    private getScrollRect;
    /**
     * Determines if an element is the document element.
     * @param element `WebElement` to test.
     */
    private isDocElement;
    /**
     * Round all of the Rect keys.
     */
    private round;
}
export {};
