"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const pngjs_1 = require("pngjs");
const elementScreenshot_1 = require("./elementScreenshot");
class Screenshot {
    /**
     * Convert the name and directory of the screenshot into a path.
     */
    static buildPath(name, driver, screenshotsDir) {
        return __awaiter(this, void 0, void 0, function* () {
            const capabilities = yield driver.getCapabilities();
            const size = yield driver.manage().window().getSize();
            const version = (capabilities.get("version") || capabilities.get("browserVersion"));
            const screenshotPath = path.resolve(screenshotsDir);
            return path.join(screenshotPath, name)
                .replace("{browserName}", capabilities.get("browserName"))
                .replace("{browserVersion}", version)
                .replace("{browserSize}", `${size.width}x${size.height}`)
                .replace(/.png$/, "")
                .split(path.sep)
                .map((value) => value.replace(/\W+/gi, "-"))
                .join(path.sep) + ".png";
        });
    }
    /**
     * Screenshot the browser or element.
     */
    static take(driver, element, elementContent) {
        return __awaiter(this, void 0, void 0, function* () {
            if (element) {
                return new Screenshot(yield elementScreenshot_1.default(element, elementContent));
            }
            else {
                return new Screenshot(new Buffer(yield driver.takeScreenshot(), "base64"));
            }
        });
    }
    /*
     * Load a screenshot from a path.
     */
    static fromPath(filePath) {
        return new Screenshot(fs.readFileSync(filePath));
    }
    constructor(source) {
        this.png = source instanceof Buffer ? pngjs_1.PNG.sync.read(source) : source;
    }
    /**
     * Determine if the current screenshot is the same size as another screenshot.
     */
    isSameSize(compareShot) {
        const sameWidth = (compareShot.png.width === this.png.width);
        const sameHeight = (compareShot.png.height === this.png.height);
        return (sameWidth && sameHeight);
    }
    /**
     * Compute the difference of the current screenshot with another screenshot by percentage of pixels.
     */
    percentDiff(diffShot) {
        let pixelDiff = 0;
        const bufferLength = this.png.data.length;
        // Default to 100% diff if images are not the same size.
        if (!this.isSameSize(diffShot)) {
            return 1;
        }
        for (let x = 0; x < bufferLength; x++) {
            if (this.png.data[x] !== diffShot.png.data[x]) {
                pixelDiff++;
            }
        }
        return pixelDiff / (this.png.width * this.png.height);
    }
    /**
     * Save a screenshot to a path.
     */
    saveToPath(filePath) {
        const basePath = filePath.slice(0, filePath.lastIndexOf(path.basename(filePath)));
        fs.mkdirpSync(basePath);
        fs.writeFileSync(filePath, pngjs_1.PNG.sync.write(this.png));
    }
}
exports.Screenshot = Screenshot;
//# sourceMappingURL=screenshot.js.map